@@ -30,7 +30,8 @@ class LibraryExperiment(object):
                  use_barcodes, 
                  bar_upstream,
                  bar_downstream,
-                 filter_thr):
+                 filter_thr,
+                 min_counts):
         """
         
 
@@ -79,6 +80,7 @@ class LibraryExperiment(object):
         self.exp_design = exp_design
         self.use_barcodes = use_barcodes
         self.filter_thr = filter_thr
+        self.min_counts = min_counts
         if use_barcodes:
             self.bar_upstream = bar_upstream
             self.bar_downstream = bar_downstream
@@ -173,11 +175,13 @@ class LibraryExperiment(object):
 
         count_mat = get_count_matrix(encoded_ids, bowtie_res, self)
         count_mat.to_csv("count_matrix.csv", index=False, float_format="%.0f")
-        
-        filtered_count_mat = filter_barcodes(count_mat, self)
-        filtered_count_mat.to_csv("filtered_count_matrix.csv", index=False, float_format="%.0f")
-        
-        self.count_mat = filtered_count_mat
+        if barcode_only:
+            self.count_mat = count_mat
+        else:
+            filtered_count_mat = filter_barcodes(count_mat, self)
+            filtered_count_mat.to_csv("filtered_count_matrix.csv", index=False, float_format="%.0f")
+            
+            self.count_mat = filtered_count_mat
 
 
         
