@@ -85,7 +85,8 @@ def run(input_dir, exp_design, cores,map_quality,seq_quality,gb_ref, bowtie_ref,
     
     experiment = LibraryExperiment(cores,map_quality,seq_quality,gb_ref, bowtie_ref, 
                                     tn_seq, tn_mismatch, input_dir, exp_design,
-                                    use_barcodes, bar_upstream, bar_downstream, filter_thr)
+                                    use_barcodes, bar_upstream, bar_downstream, filter_thr,
+                                    min_counts)
     experiment.pools
     print("Found", str(len(experiment.file2pool)), "input files!")
     print("Running pysudoku with", str(len(experiment.pools)), "pools and ",
@@ -165,7 +166,7 @@ def run_on_barcodes(input_dir, exp_design, cores,map_quality,seq_quality,
     gb_ref = None
     experiment = LibraryExperiment(cores,map_quality,seq_quality,gb_ref, bowtie_ref, 
                                     tn_seq, tn_mismatch, input_dir, exp_design,
-                                    use_barcodes, bar_upstream, bar_downstream, filter_thr)
+                                    use_barcodes, bar_upstream, bar_downstream, filter_thr, min_counts)
     experiment.pools
     print("Found", str(len(experiment.file2pool)), "input files!")
     print("Running pysudoku with", str(len(experiment.pools)), "pools and ",
@@ -209,7 +210,7 @@ def deconvolve(count_matrix, exp_design, cores, gb_ref, filter_thr) :
    
     experiment = LibraryExperiment(cores,map_quality =None,seq_quality=None,gb_ref=gb_ref, bowtie_ref=None, 
                                     tn_seq=None, tn_mismatches=None, input_dir=None, exp_design=exp_design,
-                                    use_barcodes=True, bar_upstream=None, bar_downstream=None, filter_thr=filter_thr)
+                                    use_barcodes=True, bar_upstream=None, bar_downstream=None, filter_thr=filter_thr, min_counts=5)
     c = pd.read_csv(count_matrix)
     experiment.count_mat = c
     print("Inferring most likely locations and writing location summary!")
